==> haskell-servant-swagger-1.1.7-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.7
id: servant-swagger-1.1.7-JTtPkRo9SFfGSs0A9ZOZr7
key: servant-swagger-1.1.7-JTtPkRo9SFfGSs0A9ZOZr7
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 3f474585e90ee7fbd4ad30a4f3c5ef4a
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-swagger-1.1.7
hs-libraries: HSservant-swagger-1.1.7-JTtPkRo9SFfGSs0A9ZOZr7
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-2f2DWYxbnUnFm9iFQHaKmb
    aeson-pretty-0.8.7-9uQihh1xr4RLeX7r4Spw5O base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    hspec-2.7.0-8sxwDBlJphv23imnZZTjUr
    http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
    insert-ordered-containers-0.2.1.0-E1mK80WkbRIAZnEhlqALKP
    lens-4.17.1-L7DHqflYde2JbmoGM5Kz62
    servant-0.16-JRJgXlaIQeR8MVEHqxWUVz
    singleton-bool-0.1.4-BswWCJ6C1foFLbVlo6nj0a
    swagger2-2.3.1.1-G8TUcZF2ymi1igC6QZ13et text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.7-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.7
id: servant-swagger-1.1.7-1rUs3X0CYVBBTCZk7y22NM
key: servant-swagger-1.1.7-1rUs3X0CYVBBTCZk7y22NM
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 5bf8ea60930bd260822882d1477e8d2e
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-swagger-1.1.7
hs-libraries: HSservant-swagger-1.1.7-1rUs3X0CYVBBTCZk7y22NM
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL
    aeson-pretty-0.8.7-LJcyTD72gZ8IVmXhVR4DkH base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    hspec-2.7.0-4m4UvDMOkIG31zAk7L72Gu
    http-media-0.7.1.3-526FRqXrDV23kO6QPxcRZi
    insert-ordered-containers-0.2.1.0-F8DywrAdFOcDyps1GAdDSx
    lens-4.17.1-Ii3Qh0jlmopECfPGkUKRMA
    servant-0.16-AZLPRUWNjSd8mAcIsuhaEm
    singleton-bool-0.1.4-BswWCJ6C1foFLbVlo6nj0a
    swagger2-2.3.1.1-FbigbCN8Bk4BPhk7TS1Jka text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
